# Emiproc

Python package for processing emission datasets and converting them
into netcdf rasters or inputs for transport models (ICON-ART, COSMO-ART, ...).

If interested in previous versions, please check the branches
dedicated to the previous releases.

## Documentation

The full documentation is hosted at https://emiproc.readthedocs.io .

## Installation 

`emiproc` can be installed with pip:

```
pip install emiproc
```

## License

This work is licensed under a BSD-3-Clause licence. See the LICENSE file for details or https://opensource.org/license/bsd-3-clause
